<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Nên nhớ vẫn còn có nhiều điều thú vị hơn bên ngoài trình duyệt này!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Phiên bản %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Giấy phép: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 là phần mềm miễn phí nhưng quá trình phát triển phần mềm này mất rất nhiều thời gian cũng như tâm sức.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Xin vui lòng &lt;a href=&apos;%1&apos;&gt;đóng góp về tài chính cho chúng tôi&lt;/a&gt; để hỗ trợ việc phát triển của %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Chuyển ngữ %1 sang ngôn ngữ của bạn bằng cách sử dụng %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Biểu tượng được thiết kế bởi %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Được phát hành với điều khoản của &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Đóng lại</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Dịch bởi Phan Anh</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Điền vào chi tiết giấy phép</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Mã:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Xin giấy phép %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Bằng cách mua phiên bản đầy đủ, bạn cũng sẽ hỗ trợ vào quá trình phát triển của phần mềm %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Sử dụng phiên bản dùng thử</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Điền vào giấy phép</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Mua giấy phép</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Tải xuống</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Bởi %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Video của tôi</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Các video chưa xem</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Lần cập nhật cuối</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Được thêm vào mới đây</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Mới vừa được xem</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Được xem nhiều nhất</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sắp xếp theo</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Đánh dấu là đã xem</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Hiển thị Cập Nhật</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Bạn không có phần đăng ký theo dõi nào. Sử dụng biểu tượng ngôi sao để đăng ký theo dõi một kênh nào đó.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Tất cả các video</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Các video chưa xem</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Hiện không có phần theo dõi đăng ký nào được cập nhật vào thời điểm này.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 lượt xem</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte/giây</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/giây</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/giây</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>giây</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>phút</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 còn lại</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 đã tải xuống trong %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Tải xuống hoàn tất</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Thay đổi vị trí...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Chọn vị trí tải về</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Vị trí tải về đã thay đổi.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Phần tải về hiện tại sẽ vẫn được lưu vào vị trí trước đó.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Đang tải về: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Tải về</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Tập tin thực thi đã được chỉnh sửa, có thể do vi-rút.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 sẽ không chạy. Hãy thử cài đặt lại.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Từ bỏ</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>cài đặt lại</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Phát/Tạm dừng</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Dừng phát sau track hiện tại</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Track tiếp theo</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Track trước đó</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Tăng âm lượng</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Giảm âm lượng</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tắt tiếng</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Tiến lên phía trước</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Lùi lại phía sau</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Tìm Kiếm</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Tìm video và kênh dựa theo từ khóa</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Duyệt tìm</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Duyệt tìm video theo thể loại</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Đăng ký theo dõi</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Đăng ký theo dõi kênh</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Tạo sự thoải mái cho chính bạn</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Lỗi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Cửa sổ</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Thu nhỏ</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Dừng lại</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Dừng phát lại và đi đến phần hiển thị tìm kiếm</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Trước đó</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Quay lại track trước đó</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>B&amp;ỏ qua</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Bỏ qua và truy cập video tiếp theo</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Phát</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Khôi phục chế độ phát lại</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Toàn màn hình</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Chuyển sang toàn màn hình</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Chế độ thu gọn</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ân danh sách phát và thanh công cụ</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Mở &amp;trang YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Truy cập trang video của YouTube và dừng chế độ phát lại</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Sao chép liên kết &amp;trên YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Sao chép đường dẫn đến video hiện tại trên YouTube vào bộ nhớ ảo</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Sao chép luồng dữ liệu &amp;video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Sao chép đường dẫn luồng video hiện tại vào bộ nhớ ảo</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Tìm các phần &amp;thuộc video</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Tìm các phần video khác theo đúng trật tự</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Loại bỏ</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Loại bỏ các video được chọn khỏi danh sách phát</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Chuyển &amp;lên</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Di chuyển các video được chọn trong danh sách phát lên trên</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Chuyển &amp;xuống</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Di chuyển các video được chọn trong danh sách phát xuống dưới</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Xóa các phần tìm kiếm gần đây</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Xóa phần lịch sử tìm kiếm. Phần này không thể hoàn tác.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Thoát</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tạm biệt bạn nhé</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 trên Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Ủng &amp;hộ tài chính</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Xin vui lòng hỗ trợ việc phát triển của %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Dịch bởi Phan Anh</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Xem thông tin về %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Tắt tiếng</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Phát theo lệnh của người dùng</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Phát theo lệnh của người dùng</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Tải về</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Hiển thị thông tin chi tiết về video được tải về</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Tải về</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Tải về video hiện tại</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp; Đăng ký theo dõi kênh</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Chia sẻ video hiện tại bằng cách sử dụng %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Đóng lại</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Nổi lên trên cùng</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Dừng phát sau video này</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Báo cáo một vấn đề...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Lọc tìm kiếm...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Nhiều hơn...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Video có liên quan</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Xem video liên quan đến video này</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Mở trong &amp;trình duyệt...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Chuyển đổi &amp;Thanh Menu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Yêu thích %1? Hãy đánh giá!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Mua %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Ứng dụng</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Chế độ phát lại</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Danh sách phát</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Chia sẻ</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Chế độ hiển thị</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Giúp đỡ</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Click vào %1 để tăng âm lượng, %2 để giảm âm lượng xuống</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Chọn vị trí nội dung của bạn</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Đang mở %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Bạn có muốn thoát khỏi %1 trong khi vẫn còn một phần tải về còn đang dang dở hay không?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Nếu bạn đóng lại %1 ngay lúc này, thì các phần tải về còn đang dang dở sẽ bị xóa mất.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Đóng lại và huỷ bỏ việc tải về</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Chờ cho đến khi phần tải về được hoàn tất</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Lỗi: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Tạm dừng</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Tạm dừng phát lại</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Đang tải...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Thoát khỏi &amp;chế độ toàn màn hình</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Thời gian còn lại: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Âm lượng ở mức %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Đã tắt âm lượng</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Đã mở lại âm lượng</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Độ phân giải video được chỉnh thành %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Chế độ riêng tư của bạn hiện đã an toàn</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Tiến Trình Tải Về Đã Hoàn Tất</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Bạn vẫn có thể truy cập thanh menu bằng cách nhấn phím ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Bạn có thể dán vào đường liên kết trên YouTube vào một ứng dụng khác</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Bạn có thể dán một đường liên kết của luồng video vào một ứng dụng khác</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Liên kết này chỉ hợp lệ trong một khoảng thời gian hạn định.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Đang tải về %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>của</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>phần</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>tập</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Được gửi từ %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Bỏ theo dõi đăng ký từ %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Đăng ký theo dõi đối với %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Hiện đã phát hành một phiên bản mới của %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 hiện đã được phát hành. Phiên bản hiện tại bạn đang sở hữu %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Bạn có muốn tải về phần này không?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Bỏ qua phiên bản này</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Thông báo cho tôi sau</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Cài đặt bản cập nhật</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Dán</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 của %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Đang chuẩn bị</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Bị lỗi</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Đã hoàn tất</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Đã dừng lại</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Dừng tiến trình tải xuống</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Hiển thị trong %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Mở thư mục gốc</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Bắt đầu lại phần tải về</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Hiển thị %1 thêm</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Không có video nào</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Không có thêm video nào nữa</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sắp xếp theo</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Mức độ liên quan</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ngày tháng</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Đếm lượt xem</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Xếp hạng</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Bất cứ lúc nào</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hôm nay</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Ngày</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Ngày</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Độ dài</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tất cả</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Ngắn</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Trung bình</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Dài</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Ít hơn 4 phút</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Giữa 4 và 20 phút</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Dài hơn 20 phút</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Chất lượng</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Đã hoàn tất</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Đã hoàn tất</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Chào mừng đến với &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>để bắt đầu xem các đoạn video.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>một từ khóa</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Nhập vào</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Các từ khóa gần đây</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Các kênh gần đây</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Nhận phiên bản đầy đủ</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Quay lại</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Chuyển tới %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Quay lại %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>&amp;Lọc tìm kiếm</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Ý của bạn là: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Thay đổi vị trí...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Phổ biến nhất</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Đang tải về phần cập nhật...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Đang tải xuống %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Đang tải về phần cập nhật...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Không thể tiếp nhận luồng video từ %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>An-giê-ri</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Ác-hen-ti-na</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Úc</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bỉ</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Bra-xin</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Ca-na-đa</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chi-lê</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Cô-lôm-bi-a</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Cộng hòa Séc</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Ai-cập</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Pháp</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Đức</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ga-na</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Hy-lạp</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hồng Kông</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hun-ga-ri</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Ấn Độ</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>In-đô-nê-xi-a</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ai-len</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Ít-ra-en</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Ý</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Nhật Bản</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Gi-oa-đan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Ken-ia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Ma-lay-xi-a</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mê-hi-cô</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Ma-rốc</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Hà Lan</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Niu Xi-lân</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Ni-giê-ri-a</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Pê-ru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Phi-li-pin</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Ba Lan</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Nga</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>A-rập Xau-đi</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Xin-ga-po</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Nam Phi</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Hàn Quốc</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Tây Ban Nha</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Thuỵ Điển</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Đài Loan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tu-ni-xi-a</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Thổ Nhĩ Kỳ</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>U-gan-đa</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Các Tiểu Vương quốc A-rập Thống nhất</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Vương quốc Anh</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>De-men</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Toàn thế giới</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Không thể tiếp nhận luồng video từ %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Hiện đã phát hành một phiên bản mới của %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 hiện đã được phát hành. Phiên bản hiện tại bạn đang sở hữu %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Bạn có muốn tải về phần này không?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Thông báo cho tôi sau</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>